==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cave/dialogs_en.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")

dialogId("jes-v-tojo", "font_big", "Well, yes.")

dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")

dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")

dialogId("jes-v-uzke", "font_big", "It`s too narrow for me. You have to do it on your own down there.")

dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")

dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")

dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")

dialogId("jes-m-deprese", "font_small", "Don`t be depressive. We will solve this in no time.")

dialogId("jes-v-nevim", "font_big", "I am not so sure.")

dialogId("jes-m-takvidis", "font_small", "See? You are here.")

dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")

dialogId("jes-m-potvora1", "font_small", "This is an abomination.")

dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")

dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")

dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")

dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")

dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")

dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")

dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")

dialogId("jes-v-netopyr1", "font_big", "It`s a sculpture of bat.")

dialogId("jes-m-netopyr2", "font_small", "It`s a stalagmite shaped as a bat.")

dialogId("jes-v-netopyr2", "font_big", "It`s a plain stalagmite.")

dialogId("jes-m-netopyr3", "font_small", "It`s just an ordinary piece of rock.")

dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster`.")

dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination`.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cave/dialogs_en.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")

dialogId("jes-v-tojo", "font_big", "Well, yes.")

dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")

dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")

dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")

dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")

dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")

dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")

dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")

dialogId("jes-v-nevim", "font_big", "I am not so sure.")

dialogId("jes-m-takvidis", "font_small", "See? You are here.")

dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")

dialogId("jes-m-potvora1", "font_small", "This is an abomination.")

dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")

dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")

dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")

dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")

dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")

dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")

dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")

dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")

dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")

dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")

dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")

dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")

dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
